function merge(tbls)
	local res = {}
	for i,v in ipairs(tbls) do
		for i2,v2 in ipairs(v) do
			table.insert(res,v2)
		end
	end
	
	return res
end

function allExcept(tbls, except)
	local tomerge = {}
	for i,v in pairs(tbls) do
		if i~=except then
			table.insert(tomerge, v)
		end
	end
	return merge(tomerge)
end

--list of upgrades from created groups, hidden on planner, mfd; late activation
upgrades = {
	smallAirfield = {
		blue = {'blueGroup1','blueGroup2','blueGroup3','blueGroup4'},
		red = {'redGroup1','redGroup2','redGroup3','redGroup4'}
	},
	smallAirfieldPlus = {
		blue = {'blueGroup1','blueGroup2','blueGroup3','blueGroup4', 'blueGroup5'},
		red = {'redGroup1','redGroup2','redGroup3','redGroup4', 'redGroup5'}
	},
	largeAirfield = {
		blue = {'blueGroup1','blueGroup2','blueGroup3','blueGroup4', 'blueGroup5', 'blueGroup6'},
		red = {'redGroup1','redGroup2','redGroup3','redGroup4', 'redGroup5', 'redGroup6'}
	},
	smallSAMSite = {
		blue = {'blueGroup1','blueSmallSAM', 'blueGroup2', 'blueGroup3', 'blueGroup4', 'blueGroup5'},
		red = {'redGroup1','redSmallSAM', 'redGroup2', 'redGroup3', 'redGroup4', 'redGroup5'}
	},
	largeSAMSite = {
		blue = {'blueGroup1','blueLargeSAM', 'blueGroup2', 'blueGroup3', 'blueGroup4', 'blueGroup5', 'blueGroup6'},
		red = {'redGroup1', 'redGroup2', 'redGroup3','redLargeSAM','redGroup4','redGroup5', 'redGroup6'}
	},
	carrierGroup = {
		blue = {'blueCarrierGroupInvis'},
		red = {}
	},
	farp = {
		blue = {'blueGroup2'},
		red = {}
	}
}

--list of waypoints with specific data for specials
flavor = {
	aldhafraAFB = 'WPT 1\nStart zone',
	liwaAFB = 'WPT 2\nEaster Egg for 500 credits',
	albateen = 'WPT 3\nEaster Egg for 500 credits',
	sasalnakheel = 'WPT 4\n',
	abudhabiIntl = 'WPT 5\n',
	alainIntl = 'WPT 6\n',
	almaktoumIntl = 'WPT 7\n',
	alminhadAFB = 'WPT 8\n',
	fujairahIntl = 'WPT 9\n',
	bandarejask = 'WPT 10\n',
	dubaiIntl = 'WPT 11\n',
	sharjahIntl = 'WPT 12\n',
	rasalkhaimahIntl = 'WPT 13\n',
	khasab = 'WPT 14\n',
	abumusaisland = 'WPT 15\n',
	kishIntl = 'WPT 16\n',
	lavanisland = 'WPT 17\n',
	bandarlengeh = 'WPT 18\n',
	qeshmisland = 'WPT 19\n',
	havadarya = 'WPT 20\n',
	bandarabbasIntl = 'WPT 21\n',
	lar = 'WPT 22\n',
	jiroft = 'WPT 23\n',
	kerman = 'WPT 24\n',
	shirazIntl = 'WPT 25\n',
	carriergroup1 = 'Carrier Group1\n',
	carriergroup2 = 'Carrier Group2\n',
	farpberlin = 'Farp Berlin',
	farpparis = 'Farp Paris'
}

--persistence data
local filepath = 'Raiders_696CW_ColdWar_PersianGulf_Foothold.miz'
if lfs then 
	local dir = lfs.writedir()..'Missions/Saves/'
	lfs.mkdir(dir)
	filepath = dir..filepath
	env.info('Foothold - Save file path: '..filepath)
end

pathofFile = filepath

--list of zones with who owns them starting off and their level of items: 0 = neutral, 1 = red, 2 = blue
bc = BattleCommander:new(filepath, 10, 60)
zones = {
	aldhafraAFB = ZoneCommander:new({zone='Al Dhafra AFB', side=2, level=6, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.aldhafraAFB}),
	liwaAFB = ZoneCommander:new({zone='Liwa AFB', side=1, level=5, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.liwaAFB}),
	albateen = ZoneCommander:new({zone='Al-Bateen', side=1, level=4, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.albateen}),
	sasalnakheel = ZoneCommander:new({zone='Sas Al Nakheel', side=1, level=4, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.sasalnakheel}),
	abudhabiIntl = ZoneCommander:new({zone='Abu Dhabi Intl', side=1, level=5, upgrades=upgrades.smallAirfieldPlus, crates={}, flavorText=flavor.abudhabiIntl}),
	alainIntl = ZoneCommander:new({zone='Al Ain Intl', side=1, level=3, upgrades=upgrades.smallAirfieldPlus, crates={}, flavorText=flavor.alainIntl}),
	almaktoumIntl = ZoneCommander:new({zone='Al Maktoum Intl', side=1, level=3, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.almaktoumIntl}),
	alminhadAFB = ZoneCommander:new({zone='Al Minhad AFB', side=1, level=2, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.alminhadAFB}),
	fujairahIntl = ZoneCommander:new({zone='Fujairah Intl', side=1, level=3, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.fujairahIntl}),
	bandarejask = ZoneCommander:new({zone='Bandar-e-Jask', side=1, level=2, upgrades=upgrades.smallAirfieldPlus, crates={}, flavorText=flavor.bandarejask}),
	dubaiIntl = ZoneCommander:new({zone='Dubai Intl', side=1, level=3, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.dubaiIntl}),
	sharjahIntl = ZoneCommander:new({zone='Sharjah Intl', side=1, level=3, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.sharjahIntl}),
	rasalkhaimahIntl = ZoneCommander:new({zone='Ras Al Khaimah Intl', side=1, level=4, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.rasalkhaimahIntl}),
	khasab = ZoneCommander:new({zone='Khasab', side=1, level=2, upgrades=upgrades.smallAirfieldPlus, crates={}, flavorText=flavor.khasab}),
	abumusaisland = ZoneCommander:new({zone='Abu Musa Island', side=1, level=2, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.abumusaisland}),
	kishIntl = ZoneCommander:new({zone='Kish Intl', side=1, level=2, upgrades=upgrades.smallAirfieldPlus, crates={}, flavorText=flavor.kishIntl}),
	lavanisland = ZoneCommander:new({zone='Lavan Island', side=1, level=1, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.lavanisland}),
	bandarlengeh = ZoneCommander:new({zone='Bandar Lengeh', side=1, level=1, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.bandarlengeh}),
	qeshmisland = ZoneCommander:new({zone='Qeshm Island', side=1, level=2, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.qeshmisland}),
	havadarya = ZoneCommander:new({zone='Havadarya', side=1, level=2, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.havadarya}),
	bandarabbasIntl = ZoneCommander:new({zone='Bandar Abbas Intl', side=1, level=2, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.bandarabbasIntl}),
	lar = ZoneCommander:new({zone='Lar', side=1, level=2, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.lar}),
	jiroft = ZoneCommander:new({zone='Jiroft', side=1, level=1, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.jiroft}),
	kerman = ZoneCommander:new({zone='Kerman', side=1, level=2, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.kerman}),
	shirazIntl = ZoneCommander:new({zone='Shiraz Intl', side=1, level=1, upgrades=upgrades.smallAirfieldPlus, crates={}, flavorText=flavor.shirazIntl}),
	carriergroup1 = ZoneCommander:new({zone='Carrier Group1', side=2, level=1, upgrades=upgrades.carrierGroup, crates={}, flavorText=flavor.carriergroup1}),
	carriergroup2 = ZoneCommander:new({zone='Carrier Group2', side=2, level=1, upgrades=upgrades.carrierGroup, crates={}, flavorText=flavor.carriergroup2})
}

-- add unit groups to zones

zones.aldhafraAFB:addGroups({
	GroupCommander:new({name='blueWP1WP3Supply', mission='supply', targetzone='Al-Bateen'}),
	GroupCommander:new({name='blueWP1WP2Supply', mission='supply', targetzone='Liwa AFB'}),
	GroupCommander:new({name='blueWP1WP4Supply', mission='supply', targetzone='Sas Al Nakheel'}),
	GroupCommander:new({name='blueWP1WP5Supply', mission='supply', targetzone='Abu Dhabi Intl'})
})

zones.abudhabiIntl:addGroups({
	GroupCommander:new({name='redWP5WP2Supply', mission='supply', targetzone='Liwa AFB'}),
	GroupCommander:new({name='redWP5WP4Supply', mission='supply', targetzone='Sas Al Nakheel'}),
	GroupCommander:new({name='blueWP5WP6Supply', mission='supply', targetzone='Al Ain Intl'}),
	GroupCommander:new({name='blueWP5WP7Supply', mission='supply', targetzone='Al Maktoum Intl'}),
	GroupCommander:new({name='blueWP5WP8Supply', mission='supply', targetzone='Al Minhad AFB'}),
	GroupCommander:new({name='blueWP5WP11Supply', mission='supply', targetzone='Dubai Intl'}),
	GroupCommander:new({name='redWP5WP1Attack', mission='attack', targetzone='Al Dhafra AFB'})
})

zones.dubaiIntl:addGroups({
	GroupCommander:new({name='redWP11WP12Supply', mission='supply', targetzone='Sharjah Intl'}),
	GroupCommander:new({name='redWP11WP8Supply', mission='supply', targetzone='Al Minhad AFB'}),
	GroupCommander:new({name='redWP11WP7Supply', mission='supply', targetzone='Al Maktoum Intl'}),
	GroupCommander:new({name='redWP11WP6Supply', mission='supply', targetzone='Al Ain Intl'}),
	GroupCommander:new({name='redWP11WP9Supply', mission='supply', targetzone='Fujairah Intl'}),
	GroupCommander:new({name='redWP11WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='redWP11WP13Supply', mission='supply', targetzone='Ras Al Khaimah Intl'}),
	GroupCommander:new({name='blueWP11WP12Supply', mission='supply', targetzone='Sharjah Intl'}),
	GroupCommander:new({name='blueWP11WP8Supply', mission='supply', targetzone='Al Minhad AFB'}),
	GroupCommander:new({name='blueWP11WP7Supply', mission='supply', targetzone='Al Maktoum Intl'}),
	GroupCommander:new({name='blueWP11WP13Supply', mission='supply', targetzone='Ras Al Khaimah Intl'}),
	GroupCommander:new({name='blueWP11WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='blueWP11WP9Supply', mission='supply', targetzone='Fujairah Intl'}),
	GroupCommander:new({name='blueWP11WP14Supply', mission='supply', targetzone='Khasab'}),
	GroupCommander:new({name='redWP11Patrol', mission='patrol', targetzone='Dubai Intl'}),
	GroupCommander:new({name='redWP11WP8Attack', mission='attack', targetzone='Al Minhad AFB', trpe='surface'}),
	GroupCommander:new({name='blueWP11WP6Supply', mission='supply', targetzone='Al Ain Intl'})
})

zones.khasab:addGroups({
	GroupCommander:new({name='redWP14WP13Supply', mission='supply', targetzone='Ras Al Khaimah Intl'}),
	GroupCommander:new({name='redWP14WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='redWP14WP10Supply', mission='supply', targetzone='Bandar-e-Jask'}),
	GroupCommander:new({name='redWP14WP9Supply', mission='supply', targetzone='Fujairah Intl'}),
	GroupCommander:new({name='blueWP14WP13Supply', mission='supply', targetzone='Ras Al Khaimah Intl'}),
	GroupCommander:new({name='blueWP14WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='blueWP14WP10Supply', mission='supply', targetzone='Bandar-e-Jask'}),
	GroupCommander:new({name='blueWP14WP9Supply', mission='supply', targetzone='Fujairah Intl'}),
	GroupCommander:new({name='redWP14WP19Supply', mission='supply', targetzone='Qeshm Island'}),
	GroupCommander:new({name='blueWP14WP19Supply', mission='supply', targetzone='Qeshm Island'}),
	GroupCommander:new({name='redWP14Patrol', mission='patrol', targetzone='Khasab'})
})

zones.qeshmisland:addGroups({
	GroupCommander:new({name='redWP19WP14Supply', mission='supply', targetzone='Khasab'}),
	GroupCommander:new({name='redWP19WP18Supply', mission='supply', targetzone='Bandar Lengeh'}),
	GroupCommander:new({name='redWP19WP22Supply', mission='supply', targetzone='Lar'}),
	GroupCommander:new({name='redWP19WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='blueWP19WP14Supply', mission='supply', targetzone='Khasab'}),
	GroupCommander:new({name='blueWP19WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='blueWP19WP18Supply', mission='supply', targetzone='Bandar Lengeh'}),
	GroupCommander:new({name='blueWP19WP22Supply', mission='supply', targetzone='Lar'}),
	GroupCommander:new({name='redWP19WP11Attack', mission='attack', targetzone='Dubai Intl'}),
	GroupCommander:new({name='blueWP19WP21Supply', mission='supply', targetzone='Bandar Abbas Intl'})
	
})

zones.kishIntl:addGroups({
	GroupCommander:new({name='redWP16WP17Supply', mission='supply', targetzone='Lavan Island'}),
	GroupCommander:new({name='redWP16WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='redWP16WP18Supply', mission='supply', targetzone='Bandar Lengeh'}),
	GroupCommander:new({name='redWP16WP22Supply', mission='supply', targetzone='Lar'}),
	GroupCommander:new({name='redWP16WP19Supply', mission='supply', targetzone='Qeshm Island'}),
	GroupCommander:new({name='blueWP16WP22Supply', mission='supply', targetzone='Lar'}),
	GroupCommander:new({name='blueWP16WP17Supply', mission='supply', targetzone='Lavan Island'}),
	GroupCommander:new({name='blueWP16WP15Supply', mission='supply', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='blueWP16WP18Supply', mission='supply', targetzone='Bandar Lengeh'}),
	GroupCommander:new({name='blueWP16WP19Supply', mission='supply', targetzone='Qeshm Island'})
})

zones.lar:addGroups({
	GroupCommander:new({name='redWP22WP16Supply', mission='supply', targetzone='Kish Intl'}),
	GroupCommander:new({name='redWP22WP18Supply', mission='supply', targetzone='Bandar Lengeh'}),
	GroupCommander:new({name='redWP22WP17Supply', mission='supply', targetzone='Lavan Island'}),
	GroupCommander:new({name='redWP22WP20Supply', mission='supply', targetzone='Havadarya'}),
	GroupCommander:new({name='redWP22WP21Supply', mission='supply', targetzone='Bandar Abbas Intl'}),
	GroupCommander:new({name='redWP22WP10Supply', mission='supply', targetzone='Bandar-e-Jask'}),
	GroupCommander:new({name='blueWP22WP18Supply', mission='supply', targetzone='Bandar Lengeh'}),
	GroupCommander:new({name='blueWP22WP17Supply', mission='supply', targetzone='Lavan Island'}),
	GroupCommander:new({name='blueWP22WP20Supply', mission='supply', targetzone='Havadarya'}),
	GroupCommander:new({name='blueWP22WP21Supply', mission='supply', targetzone='Bandar Abbas Intl'}),
	GroupCommander:new({name='blueWP22WP16Supply', mission='supply', targetzone='Kish Intl'}),
	GroupCommander:new({name='blueWP22WP10Supply', mission='supply', targetzone='Bandar-e-Jask'}),
	GroupCommander:new({name='redWP22Patrol', mission='patrol', targetzone='Lar'}),
	GroupCommander:new({name='redWP22WP16Attack', mission='attack', targetzone='Kish Intl'})
})

zones.bandarabbasIntl:addGroups({
	GroupCommander:new({name='redWP21WP20Supply', mission='supply', targetzone='Havadarya'}),
	GroupCommander:new({name='redWP21WP10Supply', mission='supply', targetzone='Bandar-e-Jask'}),
	GroupCommander:new({name='redWP21WP23Supply', mission='supply', targetzone='Jiroft'}),
	GroupCommander:new({name='redWP21WP19Supply', mission='supply', targetzone='Qeshm Island'}),
	GroupCommander:new({name='blueWP21WP20Supply', mission='supply', targetzone='Havadarya'}),
	GroupCommander:new({name='blueWP21WP19Supply', mission='supply', targetzone='Qeshm Island'}),
	GroupCommander:new({name='blueWP21WP10Supply', mission='supply', targetzone='Bandar-e-Jask'}),
	GroupCommander:new({name='blueWP21WP23Supply', mission='supply', targetzone='Jiroft'}),
	GroupCommander:new({name='redWP21Patrol', mission='patrol', targetzone='Bandar Abbas Intl'}),
	GroupCommander:new({name='redWP21WP19Attack', mission='attack', targetzone='Qeshm Island'}),
	GroupCommander:new({name='redWP21WP20Attack', mission='attack', targetzone='Havadarya', type='surface'})
})

zones.kerman:addGroups({
	GroupCommander:new({name='redWP24WP23Supply', mission='supply', targetzone='Jiroft'}),
	GroupCommander:new({name='redWP24WP25Supply', mission='supply', targetzone='Shiraz Intl'}),
	GroupCommander:new({name='redWP24WP22Supply', mission='supply', targetzone='Lar'}),
	GroupCommander:new({name='redWP24WP21Supply', mission='supply', targetzone='Bandar Abbas Intl'}),
	GroupCommander:new({name='redWP24WP16Supply', mission='supply', targetzone='Kish Intl'}),
	GroupCommander:new({name='blueWP24WP25Supply', mission='supply', targetzone='Shiraz Intl'}),
	GroupCommander:new({name='blueWP24WP22Supply', mission='supply', targetzone='Lar'}),
	GroupCommander:new({name='blueWP24WP21Supply', mission='supply', targetzone='Bandar Abbas Intl'}),
	GroupCommander:new({name='blueWP24WP23Supply', mission='supply', targetzone='Jiroft'}),
	GroupCommander:new({name='blueWP24WP16Supply', mission='supply', targetzone='Kish Intl'}),
	GroupCommander:new({name='redWP24Patrol', mission='patrol', targetzone='Kerman'}),
	GroupCommander:new({name='redWP24WP23Attack', mission='attack', targetzone='Jiroft'})
})		

zones.liwaAFB:addGroups({
	GroupCommander:new({name='redWP2Patrol', mission='patrol', targetzone='Liwa AFB'})
})

zones.alainIntl:addGroups({
	GroupCommander:new({name='redWP6Patrol', mission='patrol', targetzone='Al Ain Intl'}),
	GroupCommander:new({name='redWP6WP1Attack', mission='attack', targetzone='Al Dhafra AFB'})
})

zones.almaktoumIntl:addGroups({
	GroupCommander:new({name='redWP7Patrol', mission='patrol', targetzone='Al Maktoum Intl'}),
	GroupCommander:new({name='redWP7WP5Attack', mission='attack', targetzone='Abu Dhabi Intl'}),
	GroupCommander:new({name='redWP7WP5Supply', mission='supply', targetzone='Abu Dhabi Intl'})	
})

zones.sharjahIntl:addGroups({
	GroupCommander:new({name='redWP12WP8Attack', mission='attack', targetzone='Al Minhad AFB'})
})

zones.rasalkhaimahIntl:addGroups({
	GroupCommander:new({name='redWP13Patrol', mission='patrol', targetzone='Ras Al Khaimah Intl'}),
	GroupCommander:new({name='redWP13WP12Attack', mission='attack', targetzone='Sharjah Intl'})
	
})

zones.abumusaisland:addGroups({
	GroupCommander:new({name='redWP15Patrol', mission='patrol', targetzone='Abu Musa Island'}),
	GroupCommander:new({name='redWP15WP7Attack', mission='attack', targetzone='Al Maktoum Intl'})
})

zones.bandarejask:addGroups({
	GroupCommander:new({name='redWP10Patrol', mission='patrol', targetzone='Bandar-e-Jask'})
})

zones.lavanisland:addGroups({
	GroupCommander:new({name='redWP16Patrol', mission='patrol', targetzone='Lavan Island'})
})

zones.shirazIntl:addGroups({
	GroupCommander:new({name='redWP25Patrol', mission='patrol', targetzone='Shiraz Intl'}),
	GroupCommander:new({name='redWP25WP22Attack', mission='attack', targetzone='Lar'})
})

zones.fujairahIntl:addGroups({
	GroupCommander:new({name='redWP9Patrol', mission='patrol', targetzone='Fujairah Intl'})
})

zones.albateen:addGroups({
	GroupCommander:new({name='redWP3WP1Attack', mission='attack', targetzone='Al Dhafra AFB', type='surface'})
})

--Critical objects


--adds visible lines of "connection" between related zones
for i,v in pairs(zones) do
	bc:addZone(v)
end

bc:addConnection("Al Dhafra AFB","Liwa AFB")
bc:addConnection("Al Dhafra AFB","Al-Bateen")
bc:addConnection("Al Dhafra AFB","Sas Al Nakheel")
bc:addConnection("Al Dhafra AFB","Abu Dhabi Intl")
bc:addConnection("Abu Dhabi Intl","Sas Al Nakheel")
bc:addConnection("Abu Dhabi Intl","Al-Bateen")
bc:addConnection("Abu Dhabi Intl","Liwa AFB")
bc:addConnection("Abu Dhabi Intl","Al Dhafra AFB")
bc:addConnection("Abu Dhabi Intl","Al Ain Intl")
bc:addConnection("Abu Dhabi Intl","Al Maktoum Intl")
bc:addConnection("Abu Dhabi Intl","Al Minhad AFB")
bc:addConnection("Abu Dhabi Intl","Dubai Intl")
bc:addConnection("Dubai Intl","Sharjah Intl")
bc:addConnection("Dubai Intl","Abu Musa Island")
bc:addConnection("Dubai Intl","Al Minhad AFB")
bc:addConnection("Dubai Intl","Al Maktoum Intl")
bc:addConnection("Dubai Intl","Fujairah Intl")
bc:addConnection("Dubai Intl","Al Ain Intl")
bc:addConnection("Dubai Intl","Ras Al Khaimah Intl")
bc:addConnection("Dubai Intl","Khasab")
bc:addConnection("Khasab","Ras Al Khaimah Intl")
bc:addConnection("Khasab","Abu Musa Island")
bc:addConnection("Khasab","Bandar-e-Jask")
bc:addConnection("Khasab","Fujairah Intl")
bc:addConnection("Khasab","Qeshm Island")
bc:addConnection("Qeshm Island","Khasab")
bc:addConnection("Qeshm Island","Bandar Lengeh")
bc:addConnection("Qeshm Island","Lar")
bc:addConnection("Qeshm Island","Abu Musa Island")
bc:addConnection("Qeshm Island","Bandar Abbas Intl")
bc:addConnection("Kish Intl","Lavan Island")
bc:addConnection("Kish Intl","Abu Musa Island")
bc:addConnection("Kish Intl","Bandar Lengeh")
bc:addConnection("Kish Intl","Lar")
bc:addConnection("Kish Intl","Qeshm Island")
bc:addConnection("Lar","Kish Intl")
bc:addConnection("Lar","Lavan Island")
bc:addConnection("Lar","Bandar Lengeh")
bc:addConnection("Lar","Havadarya")
bc:addConnection("Lar","Bandar Abbas Intl")
bc:addConnection("Lar","Bandar-e-Jask")
bc:addConnection("Bandar Abbas Intl","Havadarya")
bc:addConnection("Bandar Abbas Intl","Bandar-e-Jask")
bc:addConnection("Bandar Abbas Intl","Jiroft")
bc:addConnection("Bandar Abbas Intl","Qeshm Island")
bc:addConnection("Kerman","Jiroft")
bc:addConnection("Kerman","Shiraz Intl")
bc:addConnection("Kerman","Lar")
bc:addConnection("Kerman","Bandar Abbas Intl")
bc:addConnection("Kerman","Kish Intl")


--Mission complete msg
local checkMissionComplete = function (event, sender)
	local done = true
	for i,v in ipairs(bc:getZones()) do
		if v.side == 1 then
			done = false
			break
		end
	end
	
	if done then
		trigger.action.setUserFlag("ending", true)
		timer.scheduleFunction(endMission, {}, timer.getTime() + 20)
	end
end

for i,v in ipairs(bc:getZones()) do
	v:registerTrigger('lost', checkMissionComplete, 'missioncompleted')
end

--Disabling/losing zones (grayed out on map)


--F10 Menu Items


local upgradeMenu = nil
bc:registerShopItem('supplies', 'Resupply friendly Zone', 200, function(sender)
	if upgradeMenu then
		return 'Choose zone from F10 menu'
	end
	
	local upgradeZone = function(target)
		if upgradeMenu then
			local zn = bc:getZoneByName(target)
			if zn and zn.side==2 then
				zn:upgrade()
			else
				return 'Zone not friendly'
			end
			
			upgradeMenu = nil
		end
	end
	
	upgradeMenu = bc:showTargetZoneMenu(2, 'Select Zone to resupply', upgradeZone, 2)
	
	trigger.action.outTextForCoalition(2, 'Supplies prepared. Choose zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		params.zone:upgrade()
	else
		return 'Can only target friendly zone'
	end
end)

Group.getByName('capSouth'):destroy()
bc:registerShopItem('capS', 'CAP South (F-15C)', 150, function(sender) 
	local grname = 'capSouth'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

Group.getByName('capMiddle'):destroy()
bc:registerShopItem('capM', 'CAP Middle (F-15ESE)', 150, function(sender) 
	local grname = 'capMiddle'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

Group.getByName('capNorth'):destroy()
bc:registerShopItem('capN', 'CAP North (F-18C)', 150, function(sender) 
	local grname = 'capNorth'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

local spawnAwacs = function(sender) 
	local gr = Group.getByName('AWACSSouth')
	if Utils.isGroupActive(gr) then 
		return 'Overlord still active on 350.00 MHz AM'
	end
	mist.respawnGroup('AWACSSouth', true)
	trigger.action.outTextForCoalition(2,'Overlord active on 350.00 MHz AM',15)
end
Group.getByName('AWACSSouth'):destroy()
bc:registerShopItem('AWACS South', 'AWACS South(E-3A)', 100, spawnAwacs, spawnAwacs)

local spawnAwacs = function(sender) 
	local gr = Group.getByName('AWACSNorth')
	if Utils.isGroupActive(gr) then 
		return 'Magic still active on 355.00 MHz AM'
	end
	mist.respawnGroup('AWACSNorth', true)
	trigger.action.outTextForCoalition(2,'Magic active on 355.00 MHz AM',15)
end
Group.getByName('AWACSNorth'):destroy()
bc:registerShopItem('AWACS North', 'AWACS North (E-3A)', 100, spawnAwacs, spawnAwacs)

local spawnTanker = function(sender) 
	local gr = Group.getByName('BlueTankerBoom')
	if Utils.isGroupActive(gr) then 
		return 'Boom Tanker still active on 351.00 MHz AM, feet wet, TACAN 25X'
	end
	mist.respawnGroup('BlueTankerBoom', true)
	trigger.action.outTextForCoalition(2,'Boom Tanker active on 352.00 MHz AM, feet wet, TACAN 25X',15)
end
Group.getByName('BlueTankerBoom'):destroy()
bc:registerShopItem('Boom Tanker', 'KC-135 Boom', 100, spawnTanker, spawnTanker)

local spawnTanker = function(sender) 
	local gr = Group.getByName('BlueTankerMPRS')
	if Utils.isGroupActive(gr) then 
		return 'MPRS Tanker still active on 355.00 MHz AM, feet wet, TACAN 30X'
	end
	mist.respawnGroup('BlueTankerMPRS', true)
	trigger.action.outTextForCoalition(2,'MPRS Tanker active on 355.00 MHz AM, feet wet, TACAN 30X',15)
end
Group.getByName('BlueTankerMPRS'):destroy()
bc:registerShopItem('MPRS Tanker', 'KC-135 MPRS', 100, spawnTanker, spawnTanker)

Group.getByName('casSouth'):destroy()
local casTargetMenu = nil
bc:registerShopItem('casS', 'CAS South (F-4E-45MC)', 400, function(sender) 
	local gr = Group.getByName('casSouth')
	if Utils.isGroupActive(gr) then 
		return 'Ground attack mission still in progress'
	end
	
	mist.respawnGroup('casSouth', true)
	
	if casTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if casTargetMenu then
			if Group.getByName('casSouth') then
				local err = bc:engageZone(target, 'casSouth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'Phantoms engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			casTargetMenu = nil
		end
	end
	
	casTargetMenu = bc:showTargetZoneMenu(2, 'CAS South Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'Phantoms on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('casSouth')
		if Utils.isGroupActive(gr) then 
			return 'Ground attack mission still in progress'
		end
		
		mist.respawnGroup('casSouth', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('casSouth') then
				local err = bc:engageZone(target, 'casSouth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'Phantoms engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('casNorth'):destroy()
local casTargetMenu = nil
bc:registerShopItem('casN', 'CAS North (F-4E-45MC)', 400, function(sender) 
	local gr = Group.getByName('casNorth')
	if Utils.isGroupActive(gr) then 
		return 'Ground attack mission still in progress'
	end
	
	mist.respawnGroup('casNorth', true)
	
	if casTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if casTargetMenu then
			if Group.getByName('casN') then
				local err = bc:engageZone(target, 'casNorth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'Phantoms engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			casTargetMenu = nil
		end
	end
	
	casTargetMenu = bc:showTargetZoneMenu(2, 'CAS North Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'Phantoms on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('casNorth')
		if Utils.isGroupActive(gr) then 
			return 'Ground attack mission still in progress'
		end
		
		mist.respawnGroup('casNorth', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('casNorth') then
				local err = bc:engageZone(target, 'casNorth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'Phantoms engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('bombingSouth'):destroy()
local bomberTargetMenu = nil
bc:registerShopItem('bombS', 'Bombing run South (F-4E-45MC)', 600, function(sender) 
	local gr = Group.getByName('bombingSouth')
	if Utils.isGroupActive(gr) then 
		return 'Bombing run still in progress'
	end
	
	mist.respawnGroup('bombingSouth', true)
	
	if bomberTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if bomberTargetMenu then
			local bomb = Group.getByName('bombingSouth')
			if bomb then
				local err = bc:engageZone(target, 'bombingSouth', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-4E engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			bomberTargetMenu = nil
		end
	end
	
	bomberTargetMenu = bc:showTargetZoneMenu(2, 'Bombing run South Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F-4E on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('bombingSouth')
		if Utils.isGroupActive(gr) then 
			return 'Bombing run still in progress'
		end
		
		mist.respawnGroup('bombingSouth', true)
		
		mist.scheduleFunction(function(target)
			local bomb = Group.getByName('bombingSouth')
			if bomb then
				local err = bc:engageZone(target, 'bombingSouth', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-4E engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('bombingNorth'):destroy()
local bomberTargetMenu = nil
bc:registerShopItem('bombN', 'Bombing run North (F-4E-45MC)', 600, function(sender) 
	local gr = Group.getByName('bombingNorth')
	if Utils.isGroupActive(gr) then 
		return 'Bombing run still in progress'
	end
	
	mist.respawnGroup('bombingNorth', true)
	
	if bomberTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if bomberTargetMenu then
			local bomb = Group.getByName('bombingNorth')
			if bomb then
				local err = bc:engageZone(target, 'bombingNorth', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-4E engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			bomberTargetMenu = nil
		end
	end
	
	bomberTargetMenu = bc:showTargetZoneMenu(2, 'Bombing run North Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F-4E on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('bombingNorth')
		if Utils.isGroupActive(gr) then 
			return 'Bombing run still in progress'
		end
		
		mist.respawnGroup('bombingNorth', true)
		
		mist.scheduleFunction(function(target)
			local bomb = Group.getByName('bombingNorth')
			if bomb then
				local err = bc:engageZone(target, 'bombingNorth', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-4E engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('seadSouth'):destroy()
local seadTargetMenu = nil
bc:registerShopItem('seadS', 'SEAD South (F/A-18C)', 150, function(sender) 
	local gr = Group.getByName('seadSouth')
	if Utils.isGroupActive(gr) then 
		return 'SEAD mission still in progress'
	end
	mist.respawnGroup('seadSouth', true)
	
	if seadTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if Group.getByName('seadSouth') then
			local err = bc:engageZone(target, 'seadSouth', AI.Task.WeaponExpend.TWO)
			if err then
				return err
			end
			
			trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
		else
			trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
		end
		
		seadTargetMenu = nil
	end
	
	seadTargetMenu = bc:showTargetZoneMenu(2, 'SEAD Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F/A-18c Hornets on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('seadSouth')
		if Utils.isGroupActive(gr) then 
			return 'SEAD mission still in progress'
		end
		
		mist.respawnGroup('seadSouth', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('seadSouth') then
				local err = bc:engageZone(target, 'seadSouth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('seadNorth'):destroy()
local seadTargetMenu = nil
bc:registerShopItem('seadN', 'SEAD North (F/A-18C)', 150, function(sender) 
	local gr = Group.getByName('seadNorth')
	if Utils.isGroupActive(gr) then 
		return 'SEAD mission still in progress'
	end
	mist.respawnGroup('seadNorth', true)
	
	if seadTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if Group.getByName('seadNorth') then
			local err = bc:engageZone(target, 'seadNorth', AI.Task.WeaponExpend.TWO)
			if err then
				return err
			end
			
			trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
		else
			trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
		end
		
		seadTargetMenu = nil
	end
	
	seadTargetMenu = bc:showTargetZoneMenu(2, 'SEAD Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F/A-18c Hornets on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('seadNorth')
		if Utils.isGroupActive(gr) then 
			return 'SEAD mission still in progress'
		end
		
		mist.respawnGroup('seadNorth', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('seadNorth') then
				local err = bc:engageZone(target, 'seadNorth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('jtacDrone-Lase-1688'):destroy()
local jtacTargetMenu = nil
drone = JTAC:new({name = 'jtacDrone-Lase-1688'})
bc:registerShopItem('jtac', 'F-18C JTAC mission', 100, function(sender)
	
	if jtacTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local spawnAndOrbit = function(target)
		if jtacTargetMenu then
			local zn = bc:getZoneByName(target)
			drone:deployAtZone(zn)
			drone:showMenu()
			trigger.action.outTextForCoalition(2, 'JTAC deployed over '..target, 15)
			jtacTargetMenu = nil
		end
	end
	
	jtacTargetMenu = bc:showTargetZoneMenu(2, 'Deploy JTAC', spawnAndOrbit, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose which zone to deploy JTAC at from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		drone:deployAtZone(params.zone)
		drone:showMenu()
		trigger.action.outTextForCoalition(2, 'F-18C JTAC deployed over '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

local smoketargets = function(tz)
	local units = {}
	for i,v in pairs(tz.built) do
		local g = Group.getByName(v)
		for i2,v2 in ipairs(g:getUnits()) do
			table.insert(units, v2)
		end
	end
	
	local tgts = {}
	for i=1,3,1 do
		if #units > 0 then
			local selected = math.random(1,#units)
			table.insert(tgts, units[selected])
			table.remove(units, selected)
		end
	end
	
	for i,v in ipairs(tgts) do
		local pos = v:getPosition().p
		trigger.action.smoke(pos, 1)
	end
end

local smokeTargetMenu = nil
bc:registerShopItem('smoke', 'Smoke markers', 20, function(sender)
	if smokeTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if smokeTargetMenu then
			local tz = bc:getZoneByName(target)
			smoketargets(tz)
			smokeTargetMenu = nil
			trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..target, 15)
		end
	end
	
	smokeTargetMenu = bc:showTargetZoneMenu(2, 'Smoke marker target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose target zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		smoketargets(params.zone)
		trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

tanksMenu = nil
bc:registerShopItem('armor', 'Deploy armor (for combined arms)', 100, function(sender)
	
	if tanksMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployTanks = function(target)
		if tanksMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-tanks')
			
			tanksMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..target, 15)
		end
	end
	
	tanksMenu = bc:showTargetZoneMenu(2, 'Deploy armor (Choose friendly zone)', deployTanks, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-tanks')
		trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

artyMenu = nil
bc:registerShopItem('artillery', 'Deploy artillery (for combined arms)', 100, function(sender)
	
	if artyMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployArty = function(target)
		if artyMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-arty')
			
			artyMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..target, 15)
		end
	end
	
	artyMenu = bc:showTargetZoneMenu(2, 'Deploy artillery (Choose friendly zone)', deployArty, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-arty')
		trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

reconMenu = nil
bc:registerShopItem('recon', 'Deploy recon group (for combined arms)', 50, function(sender)
	
	if reconMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployRecon = function(target)
		if reconMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-recon')
			
			reconMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..target, 15)
		end
	end
	
	reconMenu = bc:showTargetZoneMenu(2, 'Deploy recon group (Choose friendly zone)', deployRecon, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-recon')
		trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

airdefMenu = nil
bc:registerShopItem('airdef', 'Deploy air defense (for combined arms)', 150, function(sender)
	
	if airdefMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployAirDef = function(target)
		if airdefMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-airdef')
			
			airdefMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly air defense deployed at '..target, 15)
		end
	end
	
	airdefMenu = bc:showTargetZoneMenu(2, 'Deploy air defense (Choose friendly zone)', deployAirDef, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-airdef')
		trigger.action.outTextForCoalition(2, 'Friendly air defense deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

bc:addShopItem(2, 'supplies', -1)
bc:addShopItem(2, 'jtac', -1)
bc:addShopItem(2, 'smoke', -1)

bc:addShopItem(2, 'casN', -1)
bc:addShopItem(2, 'bombN', -1)
bc:addShopItem(2, 'capN', -1)
bc:addShopItem(2, 'AWACS South', -1)
bc:addShopItem(2, 'AWACS North', -1)
bc:addShopItem(2, 'Boom Tanker', -1)
bc:addShopItem(2, 'MPRS Tanker', -1)
bc:addShopItem(2, 'seadN', -1)
bc:addShopItem(2, 'seadS', -1)

bc:addShopItem(2, 'casS', -1)
bc:addShopItem(2, 'bombS', -1)
bc:addShopItem(2, 'capS', -1)

bc:addShopItem(2, 'capM', -1)

bc:addShopItem(2, 'armor', -1)
bc:addShopItem(2, 'artillery', -1)
bc:addShopItem(2, 'recon', -1)
bc:addShopItem(2, 'airdef', -1)

supplyZones = {
	'Al Dhafra AFB', 
	'Abu Dhabi Intl', 
	'Al Maktoum Intl', 
	'Dubai Intl',
	'Khasab',
	'Kish Intl', 
	'Qeshm Island', 
	'Bandar Abbas Intl', 
	'Lar',
	'Kerman',
	'Carrier Group1',
	'Carrier Group2',
	'Farp Berlin',
	'Farp Paris',
}

--logistics commander
lc = LogisticCommander:new({battleCommander = bc, supplyZones = supplyZones})
lc:init()

--Credit amounts for kills
bc:loadFromDisk() --will load and overwrite default zone levels, sides, funds and available shop items
bc:init()
bc:startRewardPlayerContribution(15,{infantry = 10, ground = 20, sam = 40, airplane = 50, ship = 250, helicopter=50, crate=200, rescue = 100})
HercCargoDropSupply.init(bc)

--GlobalSettings.defaultRespawns[1]['supply'] = { dead=60*60, hangar=30*60, preparing=5*60}
GlobalSettings.setDifficultyScaling(1.4,1)

--create event commander
evc = EventCommander:new({decissionFrequency=45*60, decissionVariance=20*60, skipChance = 5 }) --tried decissionFrequency=15*60, decissionVariance=15*60, skipChance = 5
evc:init()

--MIST spawns of events

evtWP11arty = {
	['Dubai Intl'] = { 'evt-WP11Arty'}
}
for i,v in pairs(evtWP11arty) do
	for _,v2 in ipairs(v) do
		Group.getByName(v2):destroy()
	end
end
evc:addEvent({
	id='WP11Arty',
	action = function()
		for i,v in pairs(evtWP11arty) do
			if bc:getZoneByName(i).side == 1 then
				for _,v2 in ipairs(v) do
					mist.respawnGroup(v2, true)
				end
			end
		end
	end,
	canExecute = function()
		if math.random(1,100) < 60 then return false end --was 60, tried 85
		
		if bc:getZoneByName('Dubai Intl').side ~= 2 then return false end
		
		local canAttack = false
		for i,v in pairs(evtWP11arty) do
			if bc:getZoneByName(i).side == 1 then canAttack = true end
			
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return false end
			end
		end
		
		return canAttack
	end
})

evtWP10boatattack = {
	['Bandar-e-Jask'] = { 'evt-WP10BoatAttack'}
}
for i,v in pairs(evtWP10boatattack) do
	for _,v2 in ipairs(v) do
		Group.getByName(v2):destroy()
	end
end
evc:addEvent({
	id='WP10boatAttack',
	action = function()
		for i,v in pairs(evtWP10boatattack) do
			if bc:getZoneByName(i).side == 1 then
				for _,v2 in ipairs(v) do
					mist.respawnGroup(v2, true)
				end
			end
		end
	end,
	canExecute = function()
		if math.random(1,100) < 60 then return false end --was 60, tried 85
		
		if bc:getZoneByName('Bandar-e-Jask').side ~= 2 then return false end
		
		local canAttack = false
		for i,v in pairs(evtWP10boatattack) do
			if bc:getZoneByName(i).side == 1 then canAttack = true end
			
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return false end
			end
		end
		
		return canAttack
	end
})

Group.getByName('evt-arclight'):destroy()
evc:addEvent({
	id='arcLight',
	action = function()
		mist.respawnGroup('evt-arclight', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-arclight')
		if gr then return false end
		
		local triggers = {'Liwa AFB', 'Al Dhafra AFB', 'Al Ain Intl', 'Al-Bateen', 'Sas Al Nakheel', 'Abu Dhabi Intl', 'Al Maktoum Intl', 'Al Minhad AFB', 'Dubai Intl'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startArcLightAttack() -- called from bomber groups waypoint actions
	local tgts = {
		'Liwa AFB',
		'Al Dhafra AFB',
		'Al Ain Intl',
		'Al-Bateen',
		'Sas Al Nakheel',
		'Abu Dhabi Intl',
		'Al Maktoum Intl',
		'Al Minhad AFB',
		'Dubai Intl'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-arclight') then
			bc:engageZone(choice, 'evt-arclight',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-casSouth'):destroy()
evc:addEvent({
	id='casSouth',
	action = function()
		mist.respawnGroup('evt-casSouth', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-casSouth')
		if gr then return false end
		
		local triggers = {'Liwa AFB', 'Al Dhafra AFB', 'Al Ain Intl', 'Al-Bateen', 'Sas Al Nakheel', 'Abu Dhabi Intl', 'Al Maktoum Intl', 'Al Minhad AFB', 'Dubai Intl'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCASAttack() -- called from CAS groups waypoint actions
	local tgts = {
		'Liwa AFB',
		'Al Dhafra AFB',
		'Al Ain Intl',
		'Al-Bateen',
		'Sas Al Nakheel',
		'Abu Dhabi Intl',
		'Al Maktoum Intl',
		'Al Minhad AFB',
		'Dubai Intl'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-casSouth') then
			bc:engageZone(choice, 'evt-casSouth',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-casNorth'):destroy()
evc:addEvent({
	id='casNorth',
	action = function()
		mist.respawnGroup('evt-casNorth', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-casNorth')
		if gr then return false end
		
		local triggers = {'Lar', 'Lavan Island', 'Kish Intl', 'Bandar Lengeh', 'Qeshm Island', 'Havadarya', 'Bandar Abbas Intl'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCAS1Attack() -- called from CAS1 groups waypoint actions
	local tgts = {
		'Lar',
		'Lavan Island',
		'Kish Intl',
		'Bandar Lengeh',
		'Qeshm Island',
		'Havadarya',
		'Bandar Abbas Intl'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-cas-1') then
			bc:engageZone(choice, 'evt-cas-1',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-CarrierGroup1Attack'):destroy()
evc:addEvent({
	id='carrierAttack',
	action = function()
		mist.respawnGroup('evt-CarrierGroup1Attack', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-CarrierGroup1Attack')
		if gr then return false end
		
		local triggers = {'Carrier Group1'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCarrierAttack() -- called from carrierAttack groups waypoint actions
	local tgts = {
		'Carrier Group1'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-CarrierGroup1Attack') then
			bc:engageZone(choice, 'evt-CarrierGroup1Attack',  AI.Task.WeaponExpend.ALL)
		end
	end
end

-- System msgs for events triggered
mc = MissionCommander:new({side = 2, battleCommander = bc, checkFrequency = 45}) --was checkFrequency = 60, then 20

mc:trackMission({
	title = "Defend Dubai Intl",
	description = "The enemy is preparing an attack on Dubai Intl.",
	messageStart = "New mission: Defend Dubai Intl",
	messageEnd = "Mission ended: Defend Dubai Intl",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		for i,v in pairs(evtWP11arty) do
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return true end
			end
		end
		
		return false
	end
})

mc:trackMission({
	title = "Defend Bandar-e-Jask",
	description = "The enemy is preparing an attack on Bandar-e-Jask.",
	messageStart = "New mission: Defend Bandar-e-Jask",
	messageEnd = "Mission ended: Defend Bandar-e-Jask",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		for i,v in pairs(evtWP10boatattack) do
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return true end
			end
		end
		
		return false
	end
})

mc:trackMission({
	title = "Intercept ArchLight Bomber",
	description = "Enemy ArchLight Bomber spotted to the North\nDestroy it before it gets in range.",
	messageStart = "New mission: Intercept ArchLight Bomber",
	messageEnd = "Mission ended: Intercept ArchLight Bomber",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-archlight')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the South\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy South CAS airstrike",
	messageEnd = "Mission ended: Intercept enemy South CAS airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-casSouth')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the North\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy North CAS airstrike",
	messageEnd = "Mission ended: Intercept enemy North CAS airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-casNorth')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept Carrier Strike",
	description = "Enemy aircraft conducting an airstrike on the Carrier Group\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept Carrier Group airstrike",
	messageEnd = "Mission ended: Intercept Carrier Group airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-CarrierGroup1Attack')
		if gr then return true else return false end
	end
})

resupplyTarget = nil
mc:trackMission({
	title = function() return "Resupply "..resupplyTarget end,
	description = function() return "Deliver supplies to "..resupplyTarget end,
	messageStart = function() return "New mission: Resupply "..resupplyTarget end,
	messageEnd = function() return "Mission ended: Resupply "..resupplyTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		resupplyTarget = nil
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not resupplyTarget then return false end
		
		local targetzn = bc:getZoneByName(resupplyTarget)
		return targetzn:canRecieveSupply()
	end
})

attackTarget = nil
mc:trackMission({
	title = function() return "Attack "..attackTarget end,
	description = function() return "Destroy enemy forces at "..attackTarget end,
	messageStart = function() return "New mission: Attack "..attackTarget end,
	messageEnd = function() return "Mission ended: Attack "..attackTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		attackTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not attackTarget then return false end
		
		local targetzn = bc:getZoneByName(attackTarget)
		return targetzn.side == 1
	end
})

captureTarget = nil
mc:trackMission({
	title = function() return "Capture "..captureTarget end,
	description = function() return captureTarget.." is neutral. Capture it by delivering supplies" end,
	messageStart = function() return "New mission: Capture "..captureTarget end,
	messageEnd = function() return "Mission ended: Capture "..captureTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		captureTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not captureTarget then return false end
		
		local targetzn = bc:getZoneByName(captureTarget)
		return targetzn.side == 0 and targetzn.active
	end
})
--]]
--Functions

--function addFunds250()
	--bc:addFunds(2,250)
	--end
	
--function addFunds500()
	--bc:addFunds(2,500)
	--end
	
function addSpecialFunds500()
	bc:addFunds(2,500)
	end
	
	
function endMission()
	--trigger.action.outTextForCoalition(2, 'file path is '..pathofFile, 420)
	--io.close(pathofFile)
	--timer.scheduleFunction(delFile, {}, timer.getTime() + 10)
	--os.remove(pathofFile)
	trigger.action.setUserFlag("endMission", true)
	end
	
function generateCaptureMission()
	if captureTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 0 and v.active and v.zone ~= "Farp Berlin" and v.zone ~= "Farp Paris" then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		captureTarget = validzones[choice]
		return true
	end
end

function generateAttackMission()
	if attackTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.connections) do
		local to = bc:getZoneByName(v.to)
		local from = bc:getZoneByName(v.from)
		
		if from.side ~= to.side and from.side ~= 0  and to.side ~= 0 and from.active and to.active then
			if from.side == 1 then
				table.insert(validzones, from.zone)
			elseif to.side == 1 then
				table.insert(validzones, to.zone)
			end
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		attackTarget = validzones[choice]
		return true
	end
end

function generateSupplyMission()
	if resupplyTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 2 and v:canRecieveSupply() then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		resupplyTarget = validzones[choice]
		return true
	end
end

timer.scheduleFunction(function(_, time)
	if generateCaptureMission() then
		return time+300
	else
		return time+120
	end
end, {}, timer.getTime() + 20)

timer.scheduleFunction(function(_, time)
	if generateAttackMission() then
		return time+1500  --was 300, 600, 900
	else
		return time+1200  --was 120, 300, 600
	end
end, {}, timer.getTime() + 40)

timer.scheduleFunction(function(_, time)
	if generateSupplyMission() then
		return time+600  -- was 480
	else
		return time+600  --was 240, 360, 450
	end
end, {}, timer.getTime() + 60)

mc:init()